@@ -35,7 +35,7 @@
  * @return  An empty @ref NetplanParser
  */
 NETPLAN_PUBLIC NetplanParser*
-netplan_parser_new();
+netplan_parser_new(void);
 
 /**
  * @brief   Reset a @ref NetplanParser to its initial default values.
@@ -53,6 +53,35 @@ netplan_parser_reset(NetplanParser *npp);
 NETPLAN_PUBLIC void
 netplan_parser_clear(NetplanParser **npp);
 
+/**
+ * @brief   Set @ref NetplanParser flags.
+ * @details Parser flags are used to change the default behavior of the parser.
+ * @param[in] npp       The @ref NetplanParser to set the flags.
+ * @param[in] flags     The value of the flags. The possible values are defined in @ref NETPLAN_PARSER_FLAGS
+ * @param[out] error    Filled with a @ref NetplanError in case of failure
+ * @return              Indication of success or failure
+ */
+NETPLAN_PUBLIC gboolean
+netplan_parser_set_flags(NetplanParser* npp, unsigned int flags, NetplanError** error);
+
+/**
+ * @brief   Get @ref NetplanParser flags.
+ * @details Parser flags are used to change the default behavior of the parser.
+ * @param[in] npp   The @ref NetplanParser to get the flags from.
+ * @return          The current flags set in the parser.
+ */
+NETPLAN_PUBLIC unsigned int
+netplan_parser_get_flags(const NetplanParser* npp);
+
+/**
+ * @brief   Get @ref NetplanParser error count.
+ * @details The number of errors that were ignored when the IGNORE_ERRORS is used.
+ * @param[in] npp   The @ref NetplanParser to get the error count from.
+ * @return          The current error count.
+ */
+NETPLAN_PUBLIC unsigned int
+netplan_parser_get_error_count(const NetplanParser* npp);
+
 /**
  * @brief Parse a given YAML file and create or update the list of @ref NetplanNetDefinition inside @p npp.
  * @param[in]  npp      The @ref NetplanParser object that should contain the parsed data
