@@ -59,6 +59,7 @@ ffibuilder.cdef("""
         guint mtubytes;
         guint congestion_window;
         guint advertised_receive_window;
+        guint advmss;
     } NetplanIPRoute;
 
     // Error handling
@@ -68,6 +69,9 @@ ffibuilder.cdef("""
     // Parser
     NetplanParser* netplan_parser_new();
     void netplan_parser_clear(NetplanParser **npp);
+    gboolean netplan_parser_set_flags(NetplanParser *npp, unsigned int flags, NetplanError** error);
+    unsigned int netplan_parser_get_flags(NetplanParser *npp);
+    unsigned int netplan_parser_get_error_count(NetplanParser *npp);
     gboolean netplan_parser_load_yaml(NetplanParser* npp, const char* filename, NetplanError** error);
     gboolean netplan_parser_load_yaml_from_fd(NetplanParser* npp, int input_fd, NetplanError** error);
     gboolean netplan_parser_load_yaml_hierarchy(NetplanParser* npp, const char* rootdir, NetplanError** error);
@@ -108,6 +112,7 @@ ffibuilder.cdef("""
     gboolean netplan_netdef_get_dhcp6(const NetplanNetDefinition* netdef);
     gboolean netplan_netdef_get_link_local_ipv4(const NetplanNetDefinition* netdef);
     gboolean netplan_netdef_get_link_local_ipv6(const NetplanNetDefinition* netdef);
+    int netplan_netdef_get_accept_ra(const NetplanNetDefinition* netdef);
     ssize_t netplan_netdef_get_macaddress(const NetplanNetDefinition* netdef, char* out_buffer, size_t out_buffer_size);
 
     // NetDefinition (internal)
@@ -120,6 +125,8 @@ ffibuilder.cdef("""
     int _netplan_state_get_vf_count_for_def(
         const NetplanState* np_state, const NetplanNetDefinition* netdef, NetplanError** error);
     ssize_t _netplan_netdef_get_bond_mode(const NetplanNetDefinition* netdef, char* out_buffer, size_t out_buf_size);
+    ssize_t _netplan_netdef_get_gateway4(const NetplanNetDefinition* netdef, char* out_buffer, size_t out_buffer_size);
+    ssize_t _netplan_netdef_get_gateway6(const NetplanNetDefinition* netdef, char* out_buffer, size_t out_buffer_size);
 
     // Iterators (internal)
     struct netdef_pertype_iter* _netplan_state_new_netdef_pertype_iter(NetplanState* np_state, const char* def_type);
