@@ -167,7 +167,7 @@ int _netplan_find_yaml_glob(const char* rootdir, glob_t* out_glob)
     int rc;
     g_autofree char* rglob = g_build_path(G_DIR_SEPARATOR_S,
                                           rootdir != NULL ? rootdir : G_DIR_SEPARATOR_S,
-                                          "{lib,etc,run}/netplan/*.yaml", NULL);
+                                          "{lib,etc,run}", "netplan", "*.yaml", NULL);
     rc = glob(rglob, GLOB_BRACE, NULL, out_glob);
     if (rc != 0 && rc != GLOB_NOMATCH) {
         // LCOV_EXCL_START
