@@ -19,21 +19,57 @@
 import os
 import subprocess
 
-from .base import TestBase, exe_generate, OVS_CLEANUP
+from .base import TestBase, exe_configure, exe_generate, OVS_CLEANUP
 
 
 class TestConfigArgs(TestBase):
     '''Config file argument handling'''
 
+    def test_invalid_args(self):
+        # Systemd generator stage
+        generator = os.path.join(self.workdir.name, 'usr', 'lib', 'systemd', 'system-generators', 'netplan')
+        try:
+            subprocess.check_output([generator, '--root-dir', self.workdir.name,
+                                     self.generator_dir, self.generator_early_dir, self.generator_late_dir,
+                                     '--invalid-arg'],
+                                    stderr=subprocess.STDOUT, text=True)
+        except subprocess.CalledProcessError as e:
+            self.assertIn('failed to parse options: Unknown option --invalid-arg', e.output)
+            self.assertEqual(e.returncode, 1)
+
+        # Netplan configure stage
+        try:
+            subprocess.check_output([exe_configure, '--root-dir', self.workdir.name, '--invalid-arg'],
+                                    stderr=subprocess.STDOUT, text=True)
+        except subprocess.CalledProcessError as e:
+            self.assertIn('failed to parse options: Unknown option --invalid-arg', e.output)
+            self.assertEqual(e.returncode, 1)
+
     def test_no_files(self):
-        subprocess.check_call([exe_generate, '--root-dir', self.workdir.name])
-        self.assertEqual(os.listdir(self.workdir.name), ['run'])
+        # Systemd generator stage
+        generator = os.path.join(self.workdir.name, 'usr', 'lib', 'systemd', 'system-generators', 'netplan')
+        try:
+            subprocess.check_output([generator, '--root-dir', self.workdir.name,
+                                     self.generator_dir, self.generator_early_dir, self.generator_late_dir],
+                                    stderr=subprocess.STDOUT, text=True)
+        except subprocess.CalledProcessError as e:  # pragma: nocover (debug output)
+            self.fail(f"systemd generator failed: {e.output.strip()}")
+
+        # Netplan configure stage
+        subprocess.check_call([exe_configure, '--root-dir', self.workdir.name])
+        # nothing is generated in /run besides the netplan-ovs-cleanup.service.
+        # We only have the sd-generator in usr/lib/systemd/system-generators
+        self.assertEqual(set(os.listdir(self.workdir.name)), {'usr', 'run'})
+        self.assert_networkd(None)
+        self.assert_networkd_udev(None)
+        self.assert_nm(None)
         self.assert_nm_udev(None)
+        self.assert_ovs({'cleanup.service': OVS_CLEANUP % {'iface': 'cleanup'}})
 
     def test_no_configs(self):
         self.generate('network:\n  version: 2')
         # should not write any files
-        self.assertCountEqual(os.listdir(self.workdir.name), ['etc', 'run'])
+        self.assertEqual(set(os.listdir(self.workdir.name)) - {'usr'}, {'etc', 'run'})
         self.assert_networkd(None)
         self.assert_networkd_udev(None)
         self.assert_nm(None)
@@ -47,13 +83,19 @@ class TestConfigArgs(TestBase):
     def test_empty_config(self):
         self.generate('')
         # should not write any files
-        self.assertCountEqual(os.listdir(self.workdir.name), ['etc', 'run'])
+        self.assertEqual(set(os.listdir(self.workdir.name)) - {'usr'}, {'etc', 'run'})
         self.assert_networkd(None)
         self.assert_networkd_udev(None)
         self.assert_nm(None)
         self.assert_nm_udev(None)
         self.assert_ovs({'cleanup.service': OVS_CLEANUP % {'iface': 'cleanup'}})
 
+    def test_generate_fails_during_try(self):
+        os.makedirs(self.rundir, mode=0o700, exist_ok=True)
+        open(os.path.join(self.rundir, "netplan-try.ready"), "w").close()
+
+        self.generate('network:\n  version: 2', expect_fail=True)
+
     def test_file_args(self):
         conf = os.path.join(self.workdir.name, 'config')
         with open(conf, 'w') as f:
@@ -66,7 +108,7 @@ class TestConfigArgs(TestBase):
       dhcp4: true''', extra_args=[conf])
         # There is one systemd service unit 'netplan-ovs-cleanup.service' in /run,
         # which will always be created
-        self.assertEqual(set(os.listdir(self.workdir.name)), {'config', 'etc', 'run'})
+        self.assertEqual(set(os.listdir(self.workdir.name)) - {'usr'}, {'config', 'etc', 'run'})
         self.assert_networkd(None)
         self.assert_networkd_udev(None)
         self.assert_nm(None)
@@ -79,7 +121,11 @@ class TestConfigArgs(TestBase):
     eth0:
       dhcp4: true''', expect_fail=True, extra_args=['/non/existing/config'])
         self.assertEqual(err, 'Cannot stat /non/existing/config: No such file or directory\n')
-        self.assertEqual(os.listdir(self.workdir.name), ['etc'])
+        # No backend configuration was generated
+        self.assert_networkd(None)
+        self.assert_networkd_udev(None)
+        self.assert_nm(None)
+        self.assert_nm_udev(None)
 
     def test_help(self):
         conf = os.path.join(self.workdir.name, 'etc', 'netplan', 'a.yaml')
@@ -99,7 +145,7 @@ class TestConfigArgs(TestBase):
         self.assertEqual(err, '')
         self.assertEqual(p.returncode, 0)
         self.assertIn('Usage:', out)
-        self.assertEqual(os.listdir(self.workdir.name), ['etc'])
+        self.assertEqual(set(os.listdir(self.workdir.name)) - {'usr'}, {'etc'})
 
     def test_unknown_cli_args(self):
         p = subprocess.Popen([exe_generate, '--foo'],
@@ -163,31 +209,20 @@ class TestConfigArgs(TestBase):
   bonds:
     bond0:
       dhcp4: true
-      interfaces: [eth99.42, eth99.43, et99.46]''')
+      interfaces: [eth99.42, eth99.43, eth99.46]''')
         os.chmod(conf, mode=0o600)
-        outdir = os.path.join(self.workdir.name, 'out')
-        os.mkdir(outdir)
-
-        generator = os.path.join(self.workdir.name, 'systemd', 'system-generators', 'netplan')
-        os.makedirs(os.path.dirname(generator))
-        os.symlink(exe_generate, generator)
 
+        generator = os.path.join(self.workdir.name, 'usr', 'lib', 'systemd', 'system-generators', 'netplan')
         local_env = os.environ.copy()
         local_env['G_MESSAGES_DEBUG'] = 'all'
-        out = subprocess.check_output([generator, '--root-dir', self.workdir.name, outdir, outdir, outdir],
-                                      stderr=subprocess.STDOUT, text=True, env=local_env)
-        n = os.path.join(self.workdir.name, 'run', 'systemd', 'network', '10-netplan-eth99.network')
-        self.assertTrue(os.path.exists(n))
-        os.unlink(n)
-        n = os.path.join(self.workdir.name, 'run', 'systemd', 'network', '10-netplan-eth98.network')
-        self.assertTrue(os.path.exists(n))
-        os.unlink(n)
-        n = os.path.join(self.workdir.name, 'run', 'systemd', 'network', '10-netplan-lo.network')
-        self.assertTrue(os.path.exists(n))
-        os.unlink(n)
-        n = os.path.join(self.workdir.name, 'run', 'systemd', 'network', '10-netplan-bond0.network')
-        self.assertTrue(os.path.exists(n))
-        os.unlink(n)
+        out = ''
+        try:
+            out = subprocess.check_output([generator, '--root-dir', self.workdir.name,
+                                           self.generator_dir, self.generator_early_dir, self.generator_late_dir],
+                                          stderr=subprocess.STDOUT, text=True, env=local_env)
+        except subprocess.CalledProcessError as e:  # pragma: nocover (debug output)
+            self.fail(f"systemd generator failed: {e.output.strip()}")
+        self.assert_networkd(None)  # we're only executing the sd-generator here, not the ./configure stage
 
         # check log message about bonds wait-online
         self.assertIn('Not all bond members need to be connected for bond0 to be ready.', out)
@@ -196,65 +231,41 @@ class TestConfigArgs(TestBase):
         self.assertNotIn('making eth99.46 as "optional: true"', out)  # optional
 
         # should auto-enable networkd and -wait-online
-        service_dir = os.path.join(self.workdir.name, 'run', 'systemd', 'system')
         self.assertTrue(os.path.islink(os.path.join(
-            outdir, 'multi-user.target.wants', 'systemd-networkd.service')))
+            self.generator_dir, 'multi-user.target.wants', 'systemd-networkd.service')))
         self.assertTrue(os.path.islink(os.path.join(
-            outdir, 'network-online.target.wants', 'systemd-networkd-wait-online.service')))
-        override = os.path.join(service_dir, 'systemd-networkd-wait-online.service.d', '10-netplan.conf')
+            self.generator_dir, 'network-online.target.wants', 'systemd-networkd-wait-online.service')))
+        override = os.path.join(self.generator_late_dir, 'systemd-networkd-wait-online.service.d', '10-netplan.conf')
         self.assertTrue(os.path.isfile(override))
         with open(override, 'r') as f:
             # eth99 does not exist on the system, so will not be listed
             self.assertEqual(f.read(), '''[Unit]
 ConditionPathIsSymbolicLink=/run/systemd/generator/network-online.target.wants/systemd-networkd-wait-online.service
+After=systemd-resolved.service
 
 [Service]
 ExecStart=
 ExecStart=/lib/systemd/systemd-networkd-wait-online -i eth99.43:carrier -i lo:carrier \
 -i eth99.42:carrier -i eth99.44:degraded -i bond0:degraded
-ExecStart=/lib/systemd/systemd-networkd-wait-online --any -o routable -i eth99.43 -i eth99.45 -i bond0\n''')
-
-        # should be a no-op the second time while the stamp exists
-        out = subprocess.check_output([generator, '--root-dir', self.workdir.name, outdir, outdir, outdir],
-                                      stderr=subprocess.STDOUT, text=True)
-        self.assertFalse(os.path.exists(n))
-        self.assertIn('netplan generate already ran', out)
-
-        # after removing the stamp it generates again, and not trip over the
-        # existing enablement symlink
-        os.unlink(os.path.join(outdir, 'netplan.stamp'))
-        subprocess.check_output([generator, '--root-dir', self.workdir.name, outdir, outdir, outdir])
-        self.assertTrue(os.path.exists(n))
+ExecStart=/lib/systemd/systemd-networkd-wait-online --any --dns -o routable -i eth99.43 -i eth99.45 -i bond0\n''')
 
     def test_systemd_generator_all_optional(self):
-        conf = os.path.join(self.confdir, 'a.yaml')
-        os.makedirs(os.path.dirname(conf))
-        with open(conf, 'w') as f:
-            f.write('''network:
+        self.generate('''network:
   version: 2
   ethernets:
     eth0:
       dhcp4: true
       optional: true''')
-        outdir = os.path.join(self.workdir.name, 'out')
-        os.mkdir(outdir)
-
-        generator = os.path.join(self.workdir.name, 'systemd', 'system-generators', 'netplan')
-        os.makedirs(os.path.dirname(generator))
-        os.symlink(exe_generate, generator)
-
-        subprocess.check_call([generator, '--root-dir', self.workdir.name, outdir, outdir, outdir])
         n = os.path.join(self.workdir.name, 'run', 'systemd', 'network', '10-netplan-eth0.network')
         self.assertTrue(os.path.exists(n))
         os.unlink(n)
 
         # should auto-enable networkd but not -wait-online
-        service_dir = os.path.join(self.workdir.name, 'run', 'systemd', 'system')
         self.assertTrue(os.path.islink(os.path.join(
-            outdir, 'multi-user.target.wants', 'systemd-networkd.service')))
+            self.generator_dir, 'multi-user.target.wants', 'systemd-networkd.service')))
         self.assertFalse(os.path.islink(os.path.join(
-            outdir, 'network-online.target.wants', 'systemd-networkd-wait-online.service')))
-        override = os.path.join(service_dir, 'systemd-networkd-wait-online.service.d', '10-netplan.conf')
+            self.generator_dir, 'network-online.target.wants', 'systemd-networkd-wait-online.service')))
+        override = os.path.join(self.generator_late_dir, 'systemd-networkd-wait-online.service.d', '10-netplan.conf')
         self.assertTrue(os.path.isfile(override))
         with open(override, 'r') as f:
             self.assertEqual(f.read(), '''[Unit]
@@ -262,10 +273,7 @@ ConditionPathIsSymbolicLink=/run/systemd/generator/network-online.target.wants/s
 ''')
 
     def test_systemd_wait_online_only_non_routable(self):
-        conf = os.path.join(self.confdir, 'a.yaml')
-        os.makedirs(os.path.dirname(conf))
-        with open(conf, 'w') as f:
-            f.write('''network:
+        self.generate('''network:
   version: 2
   ethernets:
     nomatchfound: # non-optional, but cannot be matched to a physical interface on the test runner
@@ -275,16 +283,7 @@ ConditionPathIsSymbolicLink=/run/systemd/generator/network-online.target.wants/s
       link: nomatchfound
       id: 44
       link-local: [ipv6]''')
-        outdir = os.path.join(self.workdir.name, 'out')
-        os.mkdir(outdir)
-
-        generator = os.path.join(self.workdir.name, 'systemd', 'system-generators', 'netplan')
-        os.makedirs(os.path.dirname(generator))
-        os.symlink(exe_generate, generator)
-
-        service_dir = os.path.join(self.workdir.name, 'run', 'systemd', 'system')
-        override = os.path.join(service_dir, 'systemd-networkd-wait-online.service.d', '10-netplan.conf')
-        subprocess.check_call([generator, '--root-dir', self.workdir.name, outdir, outdir, outdir])
+        override = os.path.join(self.generator_late_dir, 'systemd-networkd-wait-online.service.d', '10-netplan.conf')
         self.assertTrue(os.path.isfile(override))
         with open(override, 'r') as f:
             self.assertEqual(f.read(), '''[Unit]
@@ -296,60 +295,39 @@ ExecStart=/lib/systemd/systemd-networkd-wait-online -i eth99.44:degraded
 ''')
 
     def test_systemd_wait_online_only_routable(self):
-        conf = os.path.join(self.confdir, 'a.yaml')
-        os.makedirs(os.path.dirname(conf))
-        with open(conf, 'w') as f:
-            f.write('''network:
+        self.generate('''network:
   version: 2
   bridges:
     br0:
       dhcp4: true''')
-        outdir = os.path.join(self.workdir.name, 'out')
-        os.mkdir(outdir)
-
-        generator = os.path.join(self.workdir.name, 'systemd', 'system-generators', 'netplan')
-        os.makedirs(os.path.dirname(generator))
-        os.symlink(exe_generate, generator)
-
-        subprocess.check_call([generator, '--root-dir', self.workdir.name, outdir, outdir, outdir])
         n = os.path.join(self.workdir.name, 'run', 'systemd', 'network', '10-netplan-br0.network')
         self.assertTrue(os.path.exists(n))
         os.unlink(n)
 
-        service_dir = os.path.join(self.workdir.name, 'run', 'systemd', 'system')
-        override = os.path.join(service_dir, 'systemd-networkd-wait-online.service.d', '10-netplan.conf')
-        subprocess.check_call([generator, '--root-dir', self.workdir.name, outdir, outdir, outdir])
+        override = os.path.join(self.generator_late_dir, 'systemd-networkd-wait-online.service.d', '10-netplan.conf')
         self.assertTrue(os.path.isfile(override))
         with open(override, 'r') as f:
             self.assertEqual(f.read(), '''[Unit]
 ConditionPathIsSymbolicLink=/run/systemd/generator/network-online.target.wants/systemd-networkd-wait-online.service
+After=systemd-resolved.service
 
 [Service]
 ExecStart=
 ExecStart=/lib/systemd/systemd-networkd-wait-online -i br0:degraded
-ExecStart=/lib/systemd/systemd-networkd-wait-online --any -o routable -i br0
+ExecStart=/lib/systemd/systemd-networkd-wait-online --any --dns -o routable -i br0
 ''')
 
     def test_systemd_generator_noconf(self):
-        outdir = os.path.join(self.workdir.name, 'out')
-        os.mkdir(outdir)
-
-        generator = os.path.join(self.workdir.name, 'systemd', 'system-generators', 'netplan')
-        os.makedirs(os.path.dirname(generator))
-        os.symlink(exe_generate, generator)
-
-        subprocess.check_call([generator, '--root-dir', self.workdir.name, outdir, outdir, outdir])
-        # no enablement symlink here
-        self.assertEqual(os.listdir(outdir), ['netplan.stamp'])
+        self.generate('')
+        # no enablement symlink here (in multi-user.target.wants)
+        self.assertFalse(os.path.exists(os.path.join(
+            self.generator_late_dir, 'multi-user.target.wants', 'systemd-networkd.service')))
 
     def test_systemd_generator_badcall(self):
         outdir = os.path.join(self.workdir.name, 'out')
         os.mkdir(outdir)
 
-        generator = os.path.join(self.workdir.name, 'systemd', 'system-generators', 'netplan')
-        os.makedirs(os.path.dirname(generator))
-        os.symlink(exe_generate, generator)
-
+        generator = os.path.join(self.workdir.name, 'usr', 'lib', 'systemd', 'system-generators', 'netplan')
         try:
             subprocess.check_output([generator, '--root-dir', self.workdir.name],
                                     stderr=subprocess.STDOUT, text=True)
@@ -359,56 +337,34 @@ ExecStart=/lib/systemd/systemd-networkd-wait-online --any -o routable -i br0
             self.assertIn('can not be called directly', e.output)
 
     def test_systemd_generator_escaping(self):
-        conf = os.path.join(self.confdir, 'a.yaml')
-        os.makedirs(os.path.dirname(conf))
-        with open(conf, 'w') as f:
-            f.write('''network:
+        conf = '''network:
   version: 2
   ethernets:
     lo:
       match:
         name: lo
       set-name: "a ; b\\t; c\\t; d \\n 123 ; echo "
-      addresses: ["127.0.0.1/8", "::1/128"]''')
-        os.chmod(conf, mode=0o600)
-        outdir = os.path.join(self.workdir.name, 'out')
-        os.mkdir(outdir)
+      addresses: ["127.0.0.1/8", "::1/128"]'''
+        self.generate(conf)
 
-        generator = os.path.join(self.workdir.name, 'systemd', 'system-generators', 'netplan')
-        os.makedirs(os.path.dirname(generator))
-        os.symlink(exe_generate, generator)
-
-        subprocess.check_call([generator, '--root-dir', self.workdir.name, outdir, outdir, outdir])
         n = os.path.join(self.workdir.name, 'run', 'systemd', 'network', '10-netplan-lo.network')
         self.assertTrue(os.path.exists(n))
         os.unlink(n)
 
         # should auto-enable networkd and -wait-online
-        service_dir = os.path.join(self.workdir.name, 'run', 'systemd', 'system')
         self.assertTrue(os.path.islink(os.path.join(
-            outdir, 'multi-user.target.wants', 'systemd-networkd.service')))
+            self.generator_dir, 'multi-user.target.wants', 'systemd-networkd.service')))
         self.assertTrue(os.path.islink(os.path.join(
-            outdir, 'network-online.target.wants', 'systemd-networkd-wait-online.service')))
-        override = os.path.join(service_dir, 'systemd-networkd-wait-online.service.d', '10-netplan.conf')
+            self.generator_dir, 'network-online.target.wants', 'systemd-networkd-wait-online.service')))
+        override = os.path.join(self.generator_late_dir, 'systemd-networkd-wait-online.service.d', '10-netplan.conf')
         self.assertTrue(os.path.isfile(override))
         with open(override, 'r') as f:
             # eth99 does not exist on the system, so will not be listed
             self.assertEqual(f.read(), '''[Unit]
 ConditionPathIsSymbolicLink=/run/systemd/generator/network-online.target.wants/systemd-networkd-wait-online.service
+After=systemd-resolved.service
 
 [Service]
 ExecStart=
 ExecStart=/lib/systemd/systemd-networkd-wait-online -i a \\; b\\t; c\\t; d \\n 123 \\; echo :degraded
-ExecStart=/lib/systemd/systemd-networkd-wait-online --any -o routable -i a \\; b\\t; c\\t; d \\n 123 \\; echo \n''')
-
-        # should be a no-op the second time while the stamp exists
-        out = subprocess.check_output([generator, '--root-dir', self.workdir.name, outdir, outdir, outdir],
-                                      stderr=subprocess.STDOUT, text=True)
-        self.assertFalse(os.path.exists(n))
-        self.assertIn('netplan generate already ran', out)
-
-        # after removing the stamp it generates again, and not trip over the
-        # existing enablement symlink
-        os.unlink(os.path.join(outdir, 'netplan.stamp'))
-        subprocess.check_output([generator, '--root-dir', self.workdir.name, outdir, outdir, outdir])
-        self.assertTrue(os.path.exists(n))
+ExecStart=/lib/systemd/systemd-networkd-wait-online --any --dns -o routable -i a \\; b\\t; c\\t; d \\n 123 \\; echo \n''')
