@@ -178,9 +178,9 @@ network={
 ''', new_config)
             self.assertEqual(stat.S_IMODE(os.fstat(f.fileno()).st_mode), 0o600)
         self.assertTrue(os.path.isfile(os.path.join(
-            self.workdir.name, 'run/systemd/system/netplan-wpa-wl0.service')))
+            self.generator_late_dir, 'netplan-wpa-wl0.service')))
         self.assertTrue(os.path.islink(os.path.join(
-            self.workdir.name, 'run/systemd/system/systemd-networkd.service.wants/netplan-wpa-wl0.service')))
+            self.generator_late_dir, 'systemd-networkd.service.wants/netplan-wpa-wl0.service')))
 
     def test_auth_wired(self):
         self.generate('''network:
@@ -222,13 +222,13 @@ network={
 ''')
             self.assertEqual(stat.S_IMODE(os.fstat(f.fileno()).st_mode), 0o600)
         self.assertTrue(os.path.isfile(os.path.join(
-            self.workdir.name, 'run/systemd/system/netplan-wpa-eth0.service')))
+            self.generator_late_dir, 'netplan-wpa-eth0.service')))
 
-        with open(os.path.join(self.workdir.name, 'run/systemd/system/netplan-wpa-eth0.service')) as f:
+        with open(os.path.join(self.generator_late_dir, 'netplan-wpa-eth0.service')) as f:
             self.assertEqual(f.read(), SD_WPA % {'iface': 'eth0', 'drivers': 'wired'})
             self.assertEqual(stat.S_IMODE(os.fstat(f.fileno()).st_mode), 0o644)
         self.assertTrue(os.path.islink(os.path.join(
-            self.workdir.name, 'run/systemd/system/systemd-networkd.service.wants/netplan-wpa-eth0.service')))
+            self.generator_late_dir, 'systemd-networkd.service.wants/netplan-wpa-eth0.service')))
 
 
 class TestNetworkManager(TestBase):
