@@ -474,7 +474,7 @@ class _CommonTests():
         p = subprocess.Popen(['netplan', 'apply'], stdout=subprocess.PIPE,
                              stderr=subprocess.PIPE, text=True)
         (_, err) = p.communicate()
-        self.assertIn('Cannot call Open vSwitch: ovsdb-server.service is not running.', err)
+        self.assertIn("OpenvSwitch database is not running", err)
         self.assertEqual(p.returncode, 0)
 
     def test_settings_tag_cleanup(self):
